% determines if the input signal exhibits oscillatory behaviour and evaluates the features of oscillations (frequency, period, amplitude and spikiness)
%
% INPUTS:
% sig: 1D signal 
% dt: time step
% threshold: minimal oscillation amplitudes to threat the behaviour as oscillatory
% plot_on: 0-no plotting, 1-plotting
%
% OUTPUTS:
% oscillatory: 0-NO, 1-YES
% frequency 
% amplitude 
% spikiness  
function [ oscillatory, frequency, period, amplitude, spikiness ] = measureOsc (sig, dt, threshold)
   
	% params
    minDist = 1/dt;        
	[peaks,locs] = findpeaks(sig,'MinPeakDistance',minDist);
		
	amplitude = 0;	
	period = 0;
	oscillatory = 0;
    spikiness = 0;
	frequency = 0;
		
	if (~isempty(peaks)) 
		if (length(peaks) >= 2)
			amplitude = sig(locs(end-1)) - min(sig(locs(end-1):locs(end)));
			if (amplitude > threshold)
				period = (locs(end)-locs(end-1)) *dt;
				frequency = 1/period;
				avg = mean(sig(locs(end-1):locs(end)));
				spikiness = amplitude/avg;
				oscillatory = 1;												
			else
				amplitude = 0;
			end;					
		end;
	end;
	
	
end
	
	
	