%
% INPUTS
%
% nbs: number of observed transcription factor binding sites
% scenario: linear = 0, allornone = 1 or singular = 2
% plot_on: 0 (no plotting) or 1 (plotting)
%
% OUTPUTS
%
% Nn: nuclear NF-kb concentrations in each time step of simulation
function Nn = modelAvgBasic (nbs, scenario, plot_on)

p = load('params.mat');

% species
X = zeros (1, p.steps); % nuclear NF-kB
Y = zeros (1, p.steps); % IkB mRNA	
Z = zeros (1, p.steps); % IkB 

for i = 2 : p.steps
 	
	sNn = p.Ntot * X(i-1);
	
	% multiple binding site part
	w = sNn / p.Kd;	
	n_occ = nbs * w / (1+w);
	
	%%%%%%%%%%
	% linear %
	%%%%%%%%%%
	if (scenario == 0)
		prom_act = n_occ/nbs;
    %%%%%%%%%%%%%%%
	% all or none %
	%%%%%%%%%%%%%%%
    elseif (scenario == 1)
      prom_act = power(n_occ/nbs,nbs);
    else
	%%%%%%%%%%%%
	% singular %
	%%%%%%%%%%%%
        prom_act = 1;
        if (n_occ < 1)
            prom_act = n_occ;
        end;
	end;
	
	%changes
	dX = p.A * (1-X(i-1)) * p.epsilon / (p.epsilon+Z(i-1))- p.B*Z(i-1)*X(i-1) / (p.delta + X(i-1));
	dY = prom_act - Y(i-1);
	dZ = Y(i-1) - p.C * (1-X(i-1))*Z(i-1)*p.epsilon/(p.epsilon + Z(i-1));
	
	% apply the changes
	X(i) = X(i-1) + dX * p.dTau;
	Y(i) = Y(i-1) + dY * p.dTau;
	Z(i) = Z(i-1) + dZ * p.dTau;	
end;


T=0: p.dt : p.t_end - p.dt;



Nn = p.Ntot * X;
Im = (p.kt * p.Ptot * Y) / p.gamma_m;
I = (Z * p.kt * p.ktl * p.Ptot) / power (p.gamma_m, 2);


if (plot_on == 1)

	tit = strcat('AVG: MBS NORM; NBS = ',int2str(nbs));
	if (scenario == 0)
		tit = strcat(tit,', linear');
	else if (scenario == 1)
			tit = strcat(tit,', all or none');
		else
			tit = strcat(tit,', singular');
		end;
	 end;

	 lab = strcat('A = ', num2str(p.A),', B = ', num2str(p.B),', C = ', num2str(p.C));
	 
	
	figure((nbs-1)*2+501)
	plot(T,X,T,Z,T,Y);
	legend('Nn','I','Im');
	xlabel(lab);
 
	
	
	title(tit);
	
end;

end