% saves the parameter values to params.mat, which is used by other files

% ===================================
% !!!!!! RECOMPILE AFTER EVERY CHANGE
% ===================================

% CONCENTRATION units
% uM (mamalian cells: 1E6 molecule copies approx. 1 uM)	

% minimal amplitude to treat the behaviour as oscillatory
threshold = 0.01;

% TIME settings
% time in minutes
t_end = 5000; 
dt = 0.01;
steps = t_end/dt;

% initial conditions
Ntot 	= 1;   % Total amount of Nfkb (nucleus + cytoplasm)
Ptot	= 1;   % IkB gene copies
IKK 	= 0.5; % IKK concentration is fixed - defines degradation rate of IkB in IkB:NF-kb complex

% MODEL PARAMS
% Dissociation constant
Kd      = 0.2; % 200 nM = 0.2uM , giorgetti
kNin	= 5.4/7;	% transition of NF-kb to nucleus
kIin	= 0.018;	% transition of IkB to nucleus
kIout	= 0.012;	% transition of IkB from nucleus
kNIout	= 0.83; 	% transition of IkB:NF-kb from nucleus
kt		= 1.03;		% transcription rate
ktl		= 0.24;		% translation rate
kf		= 30;		% complex IkB:NF-kb formation rate (in cytoplasm)
kfn		= 30;		% complex IkB:NF-kb formation rate (in nucleus)
kb		= 0.03;		% complex IkB:NF-kb dissociation rate (in cytoplasm)
kbn		= 0.03;		% complex IkB:NF-kb dissociation rate (in nucleus)
alpha 	= 1.05 * IKK; % degradation rate of IkB in IkB:NF-kb complex
gamma_m	= 0.017;	% mRNA degradation rate

% parameters (simplified)
KI = (kb + alpha)/kf; %0.01
KN = (kbn + kNIout)/kfn;

% RESCALED PARAMETERS
A = kNin / gamma_m;
B = kIin*kt*ktl*Ptot/(power(gamma_m,3)*Ntot);
C = alpha*Ntot/(gamma_m * KI);
delta = KN / Ntot;
epsilon = KI*power(gamma_m,2)/(kt*ktl*Ptot);
dTau = dt*gamma_m;

save ('params');